// Adapted from https://sourceforge.net/p/dadisi/code/8/tree/trunk/dadisi/
/*
 * File:   Disk.cpp
 * Author: fermat
 *
 * Created on 20. Januar 2010, 10:39
 */

#include <cassert>
#include <fstream>
#include <string>
#include <vector>

#include <global/random_slicing/Disk.hpp>

using namespace VDRIVE;
using namespace std;

Disk::Disk(int64_t id, int64_t capacity, std::string hostname,
           std::string uri) {
    this->id = id;
    this->capacity = capacity;
    this->hostname = hostname;
    this->uri = uri;
}

Disk::Disk(const Disk& orig) {
    this->id = orig.id;
    this->capacity = orig.capacity;
    this->hostname = orig.hostname;
    this->uri = orig.uri;
}

Disk::Disk(std::ifstream& in) {
    size_t str_len;
    in >> this->id >> this->capacity >> str_len;

    // read hostname
    std::vector<char> buf(str_len);
    char whitespace;
    in.read(&whitespace, 1); // read whitespace
    assert(whitespace == ' ');
    in.read(&buf[0], str_len);
    this->hostname = std::string(&buf[0], &buf[str_len]);

    // read uri
    in >> str_len;
    buf.resize(str_len);
    in.read(&whitespace, 1); // read whitespace
    assert(whitespace == ' ');
    in.read(&buf[0], str_len);
    this->uri = std::string(&buf[0], &buf[str_len]);
}

void
Disk::serialize(std::ofstream& out) {
    out << this->id << " " << this->capacity << " " << this->hostname.size()
        << " " << this->hostname << " " << this->uri.size() << " " << this->uri
        << "\n";
}

Disk::~Disk() {}

std::string
Disk::getHostname() const {
    return this->hostname;
}

void
Disk::setHostname(std::string hostname) {
    this->hostname = hostname;
}

std::string
Disk::getUri() const {
    return this->uri;
}

void
Disk::setUri(std::string uri) {
    this->uri = uri;
}

int64_t
Disk::getId() const {
    return this->id;
}

void
Disk::setId(int64_t id) {
    this->id = id;
}

int64_t
Disk::getCapacity() const {
    return this->capacity;
}

void
Disk::setCapacity(int64_t capacity) {
    this->capacity = capacity;
}
